import React, {PropTypes} from 'react';
import $ from 'jquery';
import ScrollToLink from './scroll-to-link';
import {selectBoxIsTrue} from '../helpers';
import styles from '../../src/styles/navigation.css';

const SecondaryNavigationItem = ({ url, openInNewWindow, text }) => (
    <a
        className={styles.secondaryLink}
        href={url}
        target={openInNewWindow ? '_blank' : '_self'}
    >
        {text}
    </a>
);

const SecondaryNavigation = ({ secondaryNavigationLinks }) => (
    <div className={styles.secondary}>
        <div className="container">
            <div className="row">
                {secondaryNavigationLinks.map((link, i) => (
                    <SecondaryNavigationItem {...link} key={i} />
                ))}
            </div>
        </div>
    </div>
);

const NavLink = (props) => {
    const { url, label, isCurrent, openInNewWindow } = props;
    return (
        <li>
            <a
                href={url}
                className={isCurrent ? 'nav-link-current' : null}
                target={openInNewWindow ? '_blank' : '_self'}
            >
                {label}
            </a>
        </li>
    );
};

const NavLinks = (props) => {
    const { className, navigationItems } = props;
    return (
        <ul className={className}>
            {navigationItems &&
                navigationItems.map((item, i) => (
                    <NavLink
                        key={i}
                        url={item.url}
                        label={item.label}
                        isCurrent={item.isCurrent}
                        openInNewWindow={item.openInNewWindow}
                    />
                ))
            }
            { props.showContact &&
                <li>
                    <ScrollToLink
                        href={`#contact-form`}
                        className="hidden-sm hidden-md hidden-lg"
                    >
                        {props.contactLabel}
                    </ScrollToLink>
                </li>
            }
            {props.includeSecondaryLinks &&
                props.secondaryNavigationLinks.map((link, i) => (
                    <li key={i}><SecondaryNavigationItem {...link} /></li>
                ))
            }
        </ul>
    );
};

export default class Navigation extends React.Component {
    constructor() {
        super();
        this.state = { open: false };
    }

    componentDidMount() {
        // Initialize Sticky Header
        if(this._navbar) {
            $(this._navbar).affix({
                offset: {
                    top: this.props.affixOffset
                }
            });
        }

        if(this._sideMenuToggle) {
            $(this._sideMenuToggle).sidr({
                side: 'right',
                onOpen: () => this.setState({ open: true }),
                onClose: () => this.setState({ open: false })
            });
        }
    }

    render() {
        const {
            showSecondaryNavigation,
            logoHeader,
            logoUrl,
            logoHeaderAltAttr,
            contactLabel,
            showContact
        } = this.props;
        return (
            <div>
                {showSecondaryNavigation &&
                    <SecondaryNavigation {...this.props} />
                }
                <div className={styles.navbar}>
                    <div
                        ref={(c) => this._navbar = c}
                        className={styles.navbarSection}
                    >
                        <div className={styles['hsct-container']}>
                            <div className="row">
                                <nav className={styles['hsct-navbar']} role="navigation">
                                    <div className={styles['hsct-navbar-header']}>
                                        <button
                                            type="button"
                                            className={styles['hsct-navbar-toggle']}
                                            ref={e => this._sideMenuToggle = e}
                                        >
                                            <span className="sr-only">Toggle navigation</span>
                                            {this.state.open ?
                                                'Close'
                                            :
                                                <i className="fa fa-bars" aria-hidden="true" />
                                            }
                                        </button>
                                        <a href={logoUrl} className={styles['hsct-navbar-brand']}>
                                            <img
                                                src={logoHeader}
                                                alt={logoHeaderAltAttr}
                                            />
                                        </a>
                                    </div>
                                    { showContact &&
                                        <ScrollToLink
                                            href={`#contact-form`}
                                            className="btn btn-navigation-contact-us btn-hs hs-smooth-scroll"
                                            animationTime={500}
                                        >
                                            {contactLabel}
                                        </ScrollToLink>
                                    }
                                    <NavLinks className={`nav ${styles['hsct-container']}`} {...this.props} />
                                </nav>
                            </div>
                        </div>
                    </div>
                </div>
                <div id="sidr">
                    <NavLinks {...this.props} includeSecondaryLinks />
                </div>
            </div>
        );
    }
}

Navigation.propTypes = {
    secondaryNavigationLinks: PropTypes.arrayOf(
        PropTypes.shape({
            url: PropTypes.string,
            openInNewWindow: PropTypes.bool,
            text: PropTypes.string
        })
    ).isRequired,
    navigationItems: PropTypes.arrayOf(
        PropTypes.shape({
            url: PropTypes.string.isRequired,
            label: PropTypes.string.isRequired,
            openInNewWindow: PropTypes.bool,
            isCurrent: PropTypes.bool
        })
    ).isRequired,
    showSecondaryNavigation: PropTypes.bool.isRequired,
    baseLink: PropTypes.string.isRequired,
    hasTeamMembers: PropTypes.bool,
    logoHeader: PropTypes.string.isRequired,
    logoUrl: PropTypes.string,
    logoHeaderAltAttr: PropTypes.string.isRequired,
    showHome: PropTypes.bool,
    showProducts: PropTypes.bool,
    showEvents: PropTypes.bool,
    showNews: PropTypes.bool,
    showAboutMePage: PropTypes.bool,
    contactLabel: PropTypes.string,
    showContact: PropTypes.bool,
    affixOffset: PropTypes.number
};

Navigation.defaultProps = {
    contactLabel: "Contact",
    showContact: true
};

const mapStateToProps = (state, props) => ({
    showSecondaryNavigation: selectBoxIsTrue(state.theme_data.show_secondary_navigation),
    secondaryNavigationLinks: (state.theme_data.secondary_navigation_links || []).map((link) =>
        Object.assign({ openInNewWindow: selectBoxIsTrue(link.open_in_new_window) }, link)
    ),
    baseLink: state.base_link,
    hasTeamMembers: state.profile.team_members && Boolean(state.profile.team_members.length),
    logoHeader: state.theme_data.logo_header,
    logoUrl: state.theme_data.logo_url,
    logoHeaderAltAttr: state.theme_data.footer_logo_image_alt_attr,
    navigationItems: (state.theme_data.navigation.links || []).map((item) =>
        ({
            url: selectBoxIsTrue(item.is_external) ?
                item.url :
                `${state.base_link}${item.url}`,
            label: item.text,
            openInNewWindow: selectBoxIsTrue(item.open_in_new_window),
            isCurrent: props.currentPage === item.url
        })
    ),
    contactLabel: state.theme_data.contact_form.title,
    affixOffset: 40
});
